@@ -13,7 +13,7 @@ def debug_basic(value):
                 except Exception as e:
                     tb = traceback.format_exc()
                     sg.Print(f'An error happened.  Here is the info:', e, tb)
-                    sg.popup_error(f'AN EXCEPTION OCCURRED!', e, tb)
+                    sg.popup_error(f'AN EXCEPTION OCCURRED!', "Please send us a screenshot of the error message to the side, and then click on the button to make it disappear")
             return wrap
 
         return decorate
@@ -78,7 +78,7 @@ def open_amazon_inventory_page():
     webbrowser.open(r"https://sellercentral.amazon.co.uk/listing/reports/ref=xx_invreport_dnav_xx")
 
 
-
+@debug_basic(True)
 def re_import_inventory_data():
     value_dict = {"val":None}
     get_file(text="the .txt inventory file you downloaded from amazon", 
@@ -95,6 +95,7 @@ def re_import_inventory_data():
     xw.apps.active.books.active.sheets["Inventory"].range("A1").options(index=False, header=False).value = data
     return
 
+
 def set_python_path():
     import platform
     import xlwings as xw
@@ -143,7 +144,7 @@ def return_existing_asins(inventory_sht):
     return existing_asins
 
 
-
+@debug_basic(True)
 def export_data():
     ask_to_go_to_wb_click_ok_or_terminate(name="the Arbitrage Master Sheet", keep_on_top=True, 
     affirmative_response="OK")
@@ -286,16 +287,14 @@ def export_data():
 
     xw.Book(dest_path)
 
+def export_data_process(*args, **kwargs):
+    return export_data(*args, **kwargs)
 
 @debug_basic(True)
 def generate_sku(allowed_data_types = [str]):
     """
     PLACEHOLDER
     """
-    print("hi"+1) # TO TEST THE DEBUGGER
-
-
-
     select_name_and_click_ok_or_terminate("input product names", keep_on_top=True, affirmative_response={"OK"})
     import xlwings as xw
     input_col_name_1 = xw.apps.active.books.active.selection.value
@@ -352,6 +351,13 @@ def generate_sku(allowed_data_types = [str]):
     active_cells.value = [[sku_helper(product_name)] for product_name in input_col_name_1]
 
 
+def generate_sku_process(*args, **kwargs):
+    """
+    a wrapper to use for if the underlying function has a decorator, so we can pass into multithreading.Process
+    """
+    return generate_sku(*args, **kwargs)
+
+@debug_basic(True)
 def export_shipping_sheet():
     select_name_and_click_ok_or_terminate(name="the shipping address data", keep_on_top=True,affirmative_response="OK")
     import xlwings as xw
@@ -411,6 +417,8 @@ def export_shipping_sheet():
 
     xw.apps.active.books.active.sheets["Create Shipping Plan Template"]["A1"].value = return_value
 
+def export_shipping_sheet_process(*args, **kwargs):
+    return export_shipping_sheet(*args, **kwargs)
 
 
 if __name__ == "__main__":
